@@ -1,5 +1,4 @@
-from __future__ import unicode_literals
-
+from . import global_test_init
 import unittest
 
 from sshx import tokenizer
@@ -13,6 +12,11 @@ class TokenizerTest(unittest.TestCase):
         self.assertNotEqual(s, t)
         self.assertEqual(s, tokenizer.decrypt(t, k))
 
+        s = ''
+        t = tokenizer.encrypt(s, k)
+        self.assertNotEqual(s, t)
+        self.assertEqual(s, tokenizer.decrypt(t, k))
+
     def test_encrypt_decrypt_multiple_times(self):
         data = {
             'hello1': 'key1',
@@ -23,4 +27,16 @@ class TokenizerTest(unittest.TestCase):
         for s, k in data.items():
             t = tokenizer.encrypt(s, k)
             self.assertNotEqual(s, t)
-            self.assertEqual(s, tokenizer.decrypt(t, k))
\ No newline at end of file
+            self.assertEqual(s, tokenizer.decrypt(t, k))
+
+    def test_hash(self):
+        a = 'hello world'
+        b = 'hello world'
+        self.assertNotEqual(a, tokenizer.hash(a))
+        self.assertEqual(tokenizer.hash(a), tokenizer.hash(b))
+
+
+global_test_init()
+
+if __name__ == '__main__':
+    unittest.main()
